@@ -1,4 +1,4 @@
-from palett.structs import Card
+from palett.structs.card import Card
 
 light_blue = Card(
     base='#03A9F4',
